var mongoose = require("mongoose");
var bcrypt = require("bcrypt-nodejs");
var validator = require("validator");
var plugins = require("./plugins");

var addressSchema = mongoose.Schema({
  label: {
    type: String
  },
  company: {
    type: String,
    require: true
  },
  street_address: {
    type: String,
    require: true
  },
  additional_address: {
    type: String,
    require: true
  },
  postal_code: {
    type: String,
    require: true
  },
  city: {
    type: String,
    require: true
  },
  country_code: {
    type: String,
    default: "FR"
  },
  phone: {
    type: String,
    require: true
  }
});

var userSchema = mongoose.Schema({
  email:{
    type:String,
    unique:true,
    require:true,
    lowercase:true,
    validate:[
      validator.isEmail,
      "L'adresse email est invalide."
    ]
  },
  password:{
    type:String,
    require:true,
    validate:[
      function(val){
        return val.length >= 8;
      },
      "Le mot de passe doit être de huit caractères minimum."
    ]
  },
  provider:{
    type:String,
    default:"local"
  },
  reset_password_token: String,
  reset_password_expires: Date,
  title: String,
  first_name: String,
  last_name: String,
  address: [
    addressSchema
  ]
});

userSchema.plugin(plugins.createdOn);
userSchema.plugin(plugins.modifiedOn);

userSchema.pre("save", function(next){
  var user = this;

  if (!user.isModified("password")){
    return next();
  }
  user.password = bcrypt.hashSync(user.password, bcrypt.genSaltSync(8), null);
  next();
});

// checking if password is valid
userSchema.methods.validPassword = function(password){
  return bcrypt.compareSync(password, this.password);
};

module.exports = mongoose.model("User", userSchema);
